@@ -1,7 +1,7 @@
 /*
  * This file is part of BOINC.
  * http://boinc.berkeley.edu
- * Copyright (C) 2021 University of California
+ * Copyright (C) 2020 University of California
  *
  * BOINC is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License
@@ -19,6 +19,8 @@
 package edu.berkeley.boinc;
 
 import android.app.ActivityManager;
+import android.app.NotificationChannel;
+import android.app.NotificationManager;
 import android.app.Service;
 import android.content.BroadcastReceiver;
 import android.content.ComponentName;
@@ -58,8 +60,6 @@ public class SplashActivity extends AppCompatActivity {
     private boolean mIsBound = false;
     private static IMonitor monitor = null;
 
-    private boolean mIsWelcomeSpecificFirstRun = true;
-
     private ServiceConnection mConnection = new ServiceConnection() {
         @Override
         public void onServiceConnected(ComponentName className, IBinder service) {
@@ -71,8 +71,6 @@ public class SplashActivity extends AppCompatActivity {
                 if(!monitor.boincMutexAcquired()) {
                     showNotExclusiveDialog();
                 }
-                mIsWelcomeSpecificFirstRun =
-                        BuildConfig.BUILD_TYPE.contains("xiaomi") && !monitor.getWelcomeStateFile();
                 // read log level from monitor preferences and adjust accordingly
                 Logging.setLogLevel(monitor.getLogLevel());
             }
@@ -94,10 +92,6 @@ public class SplashActivity extends AppCompatActivity {
         public void onReceive(Context context, Intent intent) {
             if(mIsBound) {
                 try {
-                    if (mIsWelcomeSpecificFirstRun) {
-                        startActivity(new Intent(SplashActivity.this, LicenseActivity.class));
-                        return;
-                    }
                     int setupStatus = SplashActivity.monitor.getSetupStatus();
                     switch(setupStatus) {
                         case ClientStatus.SETUP_STATUS_AVAILABLE:
@@ -145,6 +139,18 @@ public class SplashActivity extends AppCompatActivity {
         binding = ActivitySplashBinding.inflate(getLayoutInflater());
         setContentView(binding.getRoot());
 
+        // Create notification channel for use on API 26 and higher.
+        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
+            final String name = getString(R.string.main_notification_channel_name);
+
+            final NotificationChannel notificationChannel =
+                    new NotificationChannel("main-channel", name,
+                                            NotificationManager.IMPORTANCE_HIGH);
+            notificationChannel.setDescription(getString(R.string.main_notification_channel_description));
+
+            getSystemService(NotificationManager.class).createNotificationChannel(notificationChannel);
+        }
+
         // Use BOINC logo in Recent Apps Switcher
         if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) { // API 21
             final String label = getTitle().toString();
