@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2020 University of California
+// Copyright (C) 2018 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -472,6 +472,7 @@ void CSimpleFrame::OnMenuOpening( wxMenuEvent &event) {
     
     bool isConnected = pDoc->IsConnected();
     wxMenu* menu = event.GetMenu();
+    if (!menu) return;
     
     menu->FindItem(ID_CLOSEWINDOW, &menuFile);
     menu->FindItem(ID_HELPBOINC, &menuHelp);
@@ -963,9 +964,9 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
     // Box Sizer
     mainSizer = new wxBoxSizer(wxVERTICAL);
     mainSizer->AddSpacer(ADJUSTFORYDPI(68));
-    mainSizer->Add(m_taskPanel, 1, wxLEFT | wxRIGHT | wxEXPAND, SIDEMARGINS);
+    mainSizer->Add(m_taskPanel, 1, wxLEFT | wxRIGHT | wxEXPAND | wxALIGN_CENTER, SIDEMARGINS);
     mainSizer->AddSpacer(ADJUSTFORYDPI(8));
-    mainSizer->Add(m_projPanel, 0, wxLEFT | wxRIGHT | wxEXPAND, SIDEMARGINS);
+    mainSizer->Add(m_projPanel, 0, wxLEFT | wxRIGHT | wxEXPAND | wxALIGN_CENTER, SIDEMARGINS);
     mainSizer->AddSpacer(ADJUSTFORYDPI(8));
 
 	wxBoxSizer* buttonsSizer;
@@ -986,11 +987,11 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
                             wxDefaultPosition, wxDefaultSize, 0 );
     m_SuspendResumeButton->SetToolTip(wxEmptyString);
     
-	buttonsSizer->Add( m_SuspendResumeButton, 0, wxEXPAND, 0 );
+	buttonsSizer->Add( m_SuspendResumeButton, 0, wxEXPAND | wxALIGN_RIGHT, 0 );
     buttonsSizer->AddStretchSpacer();
 
     m_HelpButton = new wxButton( this, ID_SIMPLE_HELP, _("Help"), wxDefaultPosition, wxDefaultSize, 0 );
-	buttonsSizer->Add( m_HelpButton, 0, wxEXPAND, 0 );
+	buttonsSizer->Add( m_HelpButton, 0, wxEXPAND | wxALIGN_RIGHT, 0 );
 
     wxString helpTip;
     helpTip.Printf(_("Get help with %s"), pSkinAdvanced->GetApplicationShortName().c_str());
